
-- Local Objects
local Tablet = AceLibrary("Tablet-2.0")     -- Tooltip-style display
local Dewdrop = AceLibrary("Dewdrop-2.0");  -- Clean dropdown menu interface
local L = AceLibrary("AceLocale-2.2"):new("KA_RaidTracker")

-- Dropdown Menu Creation (thanks FarmerFu)
local MenuOpts = {
    handler = KARaidTrackerAce,
	type = "group",
	args = {
        changelog = {
            -- Latest version changes
		    type = "execute",
            order = 9,
			name = L["Current Change Log"],
            desc = L["View the KARaid Change Log"],
			func = function() ExecuteChatCommand("/ralog") end,
		},
        help = {
            -- Show help window
            type = "execute",
            order = 10,
            name = L["Help"],
            desc = L["Show KARaid Help window"],
			func = function() ExecuteChatCommand("/rahelp") end,
		},
    },
}




KARaidTrackerAce = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceDB-2.0", "FuBarPlugin-2.0");

KARaidTrackerAce.hasIcon = true;
KARaidTrackerAce.version = GetAddOnMetadata("KA_RaidTracker","Version");
KARaidTrackerAce.category = "Interface Enhancements";
KARaidTrackerAce.hasNoText = true;
KARaidTrackerAce.defaultPosition = "RIGHT";
KARaidTrackerAce.OnMenuRequest = MenuOpts

KARaidTrackerAce:RegisterDB("KARaidTrackerAceDB")

KARaidTrackerAce:RegisterDefaults("profile", {
	showwindows = {
		res = false,
		status = false,
	},
    showall = false,
    invites = {
        all = false,
        zone = false,
        minlevel = 35,
        maxlevel = 55,
    },
    quiet = false,
    rsinput = {
        show = false,
        xOfs = 0,
        yOfs = 0,
        saved = false,
    },
})

function KARaidTrackerAce:OnInitialize()
    -- If on Raid
    if GetNumRaidMembers() ~= 0 then
        -- Open Resuraction Monitor?
        --[[
        if self.db.profile.showwindows.res then 
			if ( GetNumRaidMembers() > 0 ) then
				KA_RA_ResFrame:Show();
			end
			KA_RAMenu_Options["temp"]["ShowMonitor"] = 1;
        else
			KA_RA_ResFrame:Hide();
			KA_RAMenu_Options["temp"]["ShowMonitor"] = nil;
        end
        -- Is Raid Quiet?
        if self.db.profile.quiet then
			if ( KA_RA_Level >= 1 ) then
				ExecuteChatCommand("/raquiet")
			end
        end
        ]]--
    end
end

-- Actions when Tool is Clicked with Left Button (Fubar Default)
function KARaidTrackerAce:OnClick()
	if(IsShiftKeyDown()) then
		ExecuteChatCommand("/raidtracker options");
--[[
	elseif(IsControlKeyDown()) then
        -- Do a Rly Check
        KA_RA_CheckRly();
    elseif(IsAltKeyDown()) then
        -- Do a Durability Check
        ExecuteChatCommand("/radur");
]]--
	else
        -- Open the KARaid Options
		ExecuteChatCommand("/raidtracker");
	end
end

-- Mouseover menu
function KARaidTrackerAce:OnTooltipUpdate()
    -- Get the list of Instances the player is saved to
--[[
	if(GetNumSavedInstances() > 0) then
        -- There is at least 1 instance
		cat = Tablet:AddCategory(
            -- Title
			"text", L["\nSaved Instances:"],
            -- Number of Columns
			"columns", 2,
            -- Color of Colum 1
			"child_textR", 1,
			"child_textG", 0,
			"child_textB", 1,
            -- Color of Colum 2
			"child_text2R", 1,
			"child_text2G", 0.85,
			"child_text2B", 0
		)
        -- Add the instances to the list (box)
		for i=1, GetNumSavedInstances() do
			local name, ID, remaining = GetSavedInstanceInfo(i);
			remaining = SecondsToTime(remaining);
			cat:AddLine("text", name, "text2", remaining);
			cat:AddLine("text2", "|cff00ff00"..ID);
		end
	else
        -- No instances saved
		local cat = Tablet:AddCategory(
			"text", L["\nSaved Instances:"],
			"child_textR", 1,
			"child_textG", 0,
			"child_textB", 0
		)
		cat:AddLine("text", L["No saved instances found"])
	end
]]--
    -- Tooltip
	cat = Tablet:AddCategory(
		"text", "Hint:",
		"columns", 2,
		"child_textR", 0,
		"child_textG", 1,
		"child_textB", 0,
		"child_text2R", r,
		"child_text2G", g,
		"child_text2B", b
	)
	cat:AddLine("text", "Click:", "text2", L["Raid Tracker"])
	cat:AddLine("text", "ShiftClick:", "text2", L["Raid Tracker Options"])
--	cat:AddLine("text", "CtrlClick:", "text2", L["Rly Check"])
--  cat:AddLine("text", "AtlClick:", "text2", L["Durability Check"])

end

-- Handle the Res Monitor Window
function KARaidTrackerAce:IsShowResMonitor()
	return self.db.profile.showwindows.res
end

function KARaidTrackerAce:ToggleShowResMonitor()
	self.db.profile.showwindows.res = not self.db.profile.showwindows.res
	self:Update()
	--[[
    if self.db.profile.showwindows.res then 
        -- ExecuteChatCommand("/rares show")
		if ( GetNumRaidMembers() > 0 ) then
			KA_RA_ResFrame:Show();
		end
		KA_RAMenu_Options["temp"]["ShowMonitor"] = 1;
    else
        -- ExecuteChatCommand("/rares hide")
		KA_RA_ResFrame:Hide();
		KA_RAMenu_Options["temp"]["ShowMonitor"] = nil;
    end
    ]]--
	return self.db.profile.showwindows.res
end

-- Handle the Status Monitor Window
function KARaidTrackerAce:IsShowStatusMonitor()
	return self.db.profile.showwindows.status
end

function KARaidTrackerAce:ToggleShowStatusMonitor()
	self.db.profile.showwindows.status = not self.db.profile.showwindows.status
	self:Update()
    if self.db.profile.showwindows.res then 
        -- ExecuteChatCommand("/rares show")
        --[[
		if ( GetNumRaidMembers() > 0 ) then
			KA_RAMetersFrame:Show();
		end
		]]--
    else
        -- ExecuteChatCommand("/rares hide")
		-- KA_RAMetersFrame:Hide();
    end
	return self.db.profile.showwindows.res
end

-- Handle Keyword
function KARaidTrackerAce:GetKeyword()
--[[
    local kw = KA_RAMenu_Options["temp"]["KeyWord"];
    if kw then
        return "|cFF00FF00"..kw
    else
        return "|cFFFFFF00<Disabled>"
    end
]]--
end

function KARaidTrackerAce:ChangeKeyword(keyword)
    ExecuteChatCommand("/rakeyword "..keyword)
    self:Update()
end

-- Manage Groups
function KARaidTrackerAce:IsShowAll ()
    return self.db.profile.showall
end

function KARaidTrackerAce:ToggleShowAll()
    self.db.profile.showall = not self.db.profile.showall
    self:Update()
    return self.db.profile.showall
end

function KARaidTrackerAce:ShowGroups()
--[[
    if self.db.profile.showall then
        ExecuteChatCommand("/rashow all")
    else
        ExecuteChatCommand("/rashow")
    end
]]--
end

-- Execute the /command in Chat
function ExecuteChatCommand(arg)
	if( not DEFAULT_CHAT_FRAME ) then return end
	DEFAULT_CHAT_FRAME.editBox:SetText(arg);
	ChatEdit_SendText(DEFAULT_CHAT_FRAME.editBox);
end

